# Computations

All computations must be:
- Reproducible
- Traceable to evidence
- Materialized (not recomputed in the UI)

Canonical metric registry:
- `docs/20-computations/02-canonical-metrics.md`
- `docs/20-computations/03-metric-calculations.md`

Investment compute:
- `work_graph/investment/categorize.py`
- `work_graph/investment/materialize.py`
